import processing.core.*; public class AnimationDynamic extends PMIDlet{/*  28 November 2007. UIAV Venice mobile services workshop. 
 By Nicholas Zambetti
 Example of Dynamic Live-Rendered Animation (both linear and eased)
 */

// declare the variables that describe a box
int boxX = 95;
int boxY = 20;
int boxWidth = 30;
int boxHeight = 100;

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup, Executes Once When Started, Prepares Program to Run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

public void setup()
{
  framerate(10);
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw, Executes Forever, Provides User Feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

public void draw()
{
  // draw the box
  background(100);                        // draw the background (clears the screen)
  rect(boxX, boxY, boxWidth, boxHeight);  // draw the box using variables
  
  // change variable a little bit each time we draw
  boxX = animateTo(boxX, 5, 4);           // horizontal position gradually approaches 5
  boxHeight = animateTo(boxHeight, 10, 4); // height gradually approaches 10
  // hint: for speed, instead of 4, try 2. it should be a faster animation
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Animation Functions, Provide next value given the current value, target value, and speed
/////////////////////////////////////////////////////////////////////////////////////////////

public int animateTo(int current, int target, int speed)
{
  int next = current;          // initially our next step is where we currently are
  if(target < next){           // if we need to make our value smaller...
    next = next - speed;       // make it smaller
    next = max(next, target);  // ensure that we didn't make it smaller than our target value
  } 
  else if(next < target){      // if we need to make our value bigger...
    next = next + speed;       // make it bigger
    next = min(next, target);  // ensure that we didn't make it bigger than our target value
  }
  return next;                 // return our next value
}

public int easeTo(int currentOriginal, int targetOriginal, int speed)
{
  // make values large for math
  int current = currentOriginal * 1000; // make current value large for math (e.g. 2 becomes 2000)
  int target = targetOriginal * 1000;   // make target value large for math  (e.g. 33 becomes 33000)

  // do math to calculate our next value
  int change = target - current;     // find out how much change there is (e.g. 33000 - 2000 = 31000)
  int changeLittle = change / speed; // make the change a little change   (e.g. 31000 / 4 = 7750)
  int next = current + changeLittle; // change the current value a little (e.g. 2000 + 7750 = 9750)

  // make next value small for screen
  next = next / 1000;

  // if our little change was so little that we didn't move...
  if(next == currentOriginal){
    next = targetOriginal; // our next step is our target
  }

  return next; // return our next value (e.g. 9750 / 1000 = 9, remember that we started with 2)
}
}