/*  27 November 2007. UIAV Venice mobile services workshop. 
 By Nicholas Zambetti
 Preparing to animate with multiple images 
 */

/*******************************************************************************************
 * Graphics Section
 * This section of the program is for the graphics.
 * You can think of it as the section for code that provides feedback to the user (behaviors)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Names Of Images & How Load Them
/////////////////////////////////////////////////////////////////////////////////////////////

// named references to images
PImage marioLeftRun;
PImage marioLeftJump;
PImage marioLeftWalk;
PImage marioLeftStand;
PImage marioRightRun;
PImage marioRightJump;
PImage marioRightWalk;
PImage marioRightStand;

// function to load all the images
void loadImages()
{
  marioLeftRun = loadImage("MarioLeftRun.png");
  marioLeftJump = loadImage("MarioLeftJump.png");
  marioLeftWalk = loadImage("MarioLeftWalk.png");
  marioLeftStand = loadImage("MarioLeftStand.png");
  marioRightRun = loadImage("MarioRightRun.png");
  marioRightJump = loadImage("MarioRightJump.png");
  marioRightWalk = loadImage("MarioRightWalk.png");
  marioRightStand = loadImage("MarioRightStand.png");
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Screen Drawing Functions
/////////////////////////////////////////////////////////////////////////////////////////////

// function to draw mario
void drawMario(int x, int y, int direction, int activity)
{
  if(direction == DIRECTION_RIGHT)
  {
    if(activity == ACTIVITY_STANDING){
      image(marioRightStand, x, y);
    } 
    else if(activity == ACTIVITY_WALKING){
      image(marioRightWalk, x, y);
    } 
    else if(activity == ACTIVITY_RUNNING){
      image(marioRightRun, x, y);
    } 
    else if(activity == ACTIVITY_JUMPING){
      image(marioRightJump, x, y);
    }
  }
  else if(direction == DIRECTION_LEFT)
  {
    if(activity == ACTIVITY_STANDING){
      image(marioLeftStand, x, y);
    } 
    else if(activity == ACTIVITY_WALKING){
      image(marioLeftWalk, x, y);
    } 
    else if(activity == ACTIVITY_RUNNING){
      image(marioLeftRun, x, y);
    } 
    else if(activity == ACTIVITY_JUMPING){
      image(marioLeftJump, x, y);
    }
  }
}

/*******************************************************************************************
 * Logic Section
 * This section of the program is for the logic; how we decide what graphics to show.
 * You can think of it as the section for code that captures and interprets user input (actions)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup, Executes Once When Started, Prepares Program to Run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

import processing.phone.*;
Phone myPhone;

color skyBlue;

void setup()
{
  myPhone = new Phone(this);
  myPhone.fullscreen();

  framerate(4);
  loadImages();

  skyBlue = color(86, 193, 219);
  background(skyBlue);
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Mode, Focus & Option Names (Constants)
/////////////////////////////////////////////////////////////////////////////////////////////

// names for each possible direction
int DIRECTION_LEFT = 0;
int DIRECTION_RIGHT = 1;

// names for each possible activity
int ACTIVITY_STANDING = 0;
int ACTIVITY_WALKING = 1;
int ACTIVITY_RUNNING = 2;
int ACTIVITY_JUMPING = 3;

/////////////////////////////////////////////////////////////////////////////////////////////
// State, Information Collected From Use (Variables)
/////////////////////////////////////////////////////////////////////////////////////////////

// information about Mario
int marioX = 85;                       // Mario's horizontal position on the screen
int marioY = 161;                      // Mario's vertical position on the screen
int marioDirection = DIRECTION_RIGHT;  // initially, Mario should be facing right
int marioActivity = ACTIVITY_STANDING; // initially, Mario should be standing

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw, Executes Forever, Provides User Feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

void draw()
{
  // draw the evironment
  background(skyBlue);
  
  // draw the character
  drawMario(marioX, marioY, marioDirection, marioActivity);
}

void keyPressed() // whenever a key is pressed...
{
  if(keyCode == LEFT){
    marioDirection = DIRECTION_LEFT;
    marioActivity = ACTIVITY_WALKING;
  } 
  else if(keyCode == RIGHT){
    marioDirection = DIRECTION_RIGHT;
    marioActivity = ACTIVITY_WALKING;
  }
}

void keyReleased() // whenever a key is released...
{
  marioActivity = ACTIVITY_STANDING;
}
