import processing.core.*; import processing.phone.*; public class AnimationSprite0e extends PMIDlet{/*  27 November 2007. UIAV Venice mobile services workshop. 
 By Nicholas Zambetti
 Animation with multiple images and position change, now with left and right motion
 */

/*******************************************************************************************
 * Graphics Section
 * This section of the program is for the graphics.
 * You can think of it as the section for code that provides feedback to the user (behaviors)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Names Of Images & How Load Them
/////////////////////////////////////////////////////////////////////////////////////////////

// named references to images
PImage environment;
PImage marioLeftRun;
PImage marioLeftJump;
PImage marioLeftWalk;
PImage marioLeftStand;
PImage marioRightRun;
PImage marioRightJump;
PImage marioRightWalk;
PImage marioRightStand;

// function to load all the images
public void loadImages()
{
  environment = loadImage("Environment.png");
  marioLeftRun = loadImage("MarioLeftRun.png");
  marioLeftJump = loadImage("MarioLeftJump.png");
  marioLeftWalk = loadImage("MarioLeftWalk.png");
  marioLeftStand = loadImage("MarioLeftStand.png");
  marioRightRun = loadImage("MarioRightRun.png");
  marioRightJump = loadImage("MarioRightJump.png");
  marioRightWalk = loadImage("MarioRightWalk.png");
  marioRightStand = loadImage("MarioRightStand.png");
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Drawing State, Animation (Variables)
/////////////////////////////////////////////////////////////////////////////////////////////

// animation clocks
int marioAnimationClock = 0;

/////////////////////////////////////////////////////////////////////////////////////////////
// Screen Drawing Functions
/////////////////////////////////////////////////////////////////////////////////////////////

// function to draw Mario
public void drawMario(int x, int y, int direction, int activity)
{
  // tick Mario's animation clock, tick tock
  marioAnimationClock++;

  // decide how to draw Mario
  if(direction == DIRECTION_RIGHT) // if we are standing to the right...
  {
    if(activity == ACTIVITY_STANDING) // if we are standing...
    {
      image(marioRightStand, x, y);
    } 
    else if(activity == ACTIVITY_WALKING) // if we are walking...
    {
      // reset Mario's animation clock
      if(1 < marioAnimationClock){ // if we have reached our final frame of walking (frame 2)...
        marioAnimationClock = 0;        // reset our animation clock
      }

      // use the animation clock to choose a graphic to draw
      if(marioAnimationClock == 0){   // if our clock is on the first frame...
        image(marioRightStand, x, y); // draw Mario after or before his stride
      }
      else if(marioAnimationClock == 1){ // if our clock is on the first frame...
        image(marioRightWalk, x, y);     // draw Mario mid-stride
      }
    } 
    else if(activity == ACTIVITY_RUNNING) // if we are running...
    {
      image(marioRightRun, x, y);
    } 
    else if(activity == ACTIVITY_JUMPING) // if we are jumping...
    {
      image(marioRightJump, x, y);
    }
  }
  else if(direction == DIRECTION_LEFT) // if we are standing to the left...
  {
    if(activity == ACTIVITY_STANDING){
      image(marioLeftStand, x, y);
    } 
    else if(activity == ACTIVITY_WALKING){
      // reset Mario's animation clock
      if(1 < marioAnimationClock){ // if we have reached our final frame of walking (frame 2)...
        marioAnimationClock = 0;        // reset our animation clock
      }

      // use the animation clock to choose a graphic to draw
      if(marioAnimationClock == 0){   // if our clock is on the first frame...
        image(marioLeftStand, x, y); // draw Mario after or before his stride
      }
      else if(marioAnimationClock == 1){ // if our clock is on the first frame...
        image(marioLeftWalk, x, y);     // draw Mario mid-stride
      }
    } 
    else if(activity == ACTIVITY_RUNNING){
      image(marioLeftRun, x, y);
    } 
    else if(activity == ACTIVITY_JUMPING){
      image(marioLeftJump, x, y);
    }
  }
}

/*******************************************************************************************
 * Logic Section
 * This section of the program is for the logic; how we decide what graphics to show.
 * You can think of it as the section for code that captures and interprets user input (actions)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup, Executes Once When Started, Prepares Program to Run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////


Phone myPhone;

public void setup()
{
  myPhone = new Phone(this);
  myPhone.fullscreen();

  framerate(4);
  loadImages();
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Mode, Focus & Option Names (Constants)
/////////////////////////////////////////////////////////////////////////////////////////////

// names for each possible direction
int DIRECTION_LEFT = 0;
int DIRECTION_RIGHT = 1;

// names for each possible activity
int ACTIVITY_STANDING = 0;
int ACTIVITY_WALKING = 1;
int ACTIVITY_RUNNING = 2;
int ACTIVITY_JUMPING = 3;

/////////////////////////////////////////////////////////////////////////////////////////////
// State, Information Collected From Use (Variables)
/////////////////////////////////////////////////////////////////////////////////////////////

// information about Mario
int marioX = 85;                       // Mario's horizontal position on the screen
int marioY = 161;                      // Mario's vertical position on the screen
int marioDirection = DIRECTION_RIGHT;  // initially, Mario should be facing right
int marioActivity = ACTIVITY_STANDING; // initially, Mario should be standing

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw, Executes Forever, Provides User Feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

public void draw()
{
  // draw the environment
  image(environment, 0, 0);

  // draw the character
  drawMario(marioX, marioY, marioDirection, marioActivity);

  // modify character's state according to what they are doing
  if(marioActivity == ACTIVITY_WALKING) // if Mario is walking...
  {
    if(marioDirection == DIRECTION_RIGHT){ // if Mario is walking to the right...
      marioX += 3;                         // move Mario's position to the right
    }
    else if(marioDirection == DIRECTION_LEFT){ // if Mario is walking to the left...
      marioX -= 3;                             // move Mario's position to the left
    }
  }
}

public void keyPressed() // whenever a key is pressed...
{
  if(keyCode == LEFT){
    marioDirection = DIRECTION_LEFT;
    marioActivity = ACTIVITY_WALKING;
  } 
  else if(keyCode == RIGHT){
    marioDirection = DIRECTION_RIGHT;
    marioActivity = ACTIVITY_WALKING;
  }
}

public void keyReleased() // whenever a key is released...
{
  marioActivity = ACTIVITY_STANDING;
}
}