/*  29 November 2007. UIAV Venice mobile services workshop. 
 By Nicholas Zambetti
 Version of ZoGame0l that builds the menu from many images and uses variables for focus changes
 */

/*******************************************************************************************
 * ZGame Graphics Section
 * This section of the program is for the graphics.
 * You can think of it as the section for code that provides feedback to the user (behaviors)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Names Of Graphics & How Load Them
/////////////////////////////////////////////////////////////////////////////////////////////

// named references to graphics
PImage menuBackground;
PImage menuIconFocus;
PImage menuIconGioca;
PImage menuIconAgenda;
PImage menuIconProfilo;
PImage menuIconClassifica;

// function to load all the images for the interface
void loadImages()
{
  menuBackground = loadImage("menuBackground.png");
  menuIconFocus = loadImage("menuIconFocus.png");
  menuIconGioca = loadImage("menuIconGioca.png");
  menuIconAgenda = loadImage("menuIconAgenda.png");
  menuIconProfilo = loadImage("menuIconProfilo.png");
  menuIconClassifica = loadImage("menuIconClassifica.png");
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Screen Drawing Functions
/////////////////////////////////////////////////////////////////////////////////////////////

// function to draw the menu with specified focus
int menuIconFocusX = 12; // begin with menuIconFocus X at Gioca X
int menuIconFocusY = 29; // begin with menuIconFocus Y at Gioca Y

void drawMenu(int focus)
{
  // draw background
  image(menuBackground, 0, 0);       // draw background image for the menu area

  // calculate position of focus highlight for the icon in focus
  if(focus == MENUFOCUS_GIOCA){      // if we are focused on "gioca"...
    // final position is x:12 y:29
    menuIconFocusX = 12;
    menuIconFocusY = 29;
  }
  if(focus == MENUFOCUS_AGENDA){     // if we are focused on "agenda"...
    // final position is x:12 y:107
    menuIconFocusX = 12;
    menuIconFocusY = 107;
  }
  if(focus == MENUFOCUS_CLASSIFICA){ // if we are focused on "classifica"...
    // final position is x:92 y:29
    menuIconFocusX = 92;
    menuIconFocusY = 29;
  }
  if(focus == MENUFOCUS_PROFILO){    // if we are focused on "profilo"...
     // final position is x:92 y:107
    menuIconFocusX = 92;
    menuIconFocusY = 107;
  }

  // draw the focus highlight in the calculated position 
  image(menuIconFocus, menuIconFocusX, menuIconFocusY); // often, the focus is drawn later on

  // draw main content, icons
  image(menuIconGioca, 15, 32);      // draw the "gioca" icon in the top left icon area
  image(menuIconAgenda, 15, 110);    // draw the "agenda" icon in the bottom left icon area
  image(menuIconClassifica, 95, 32); // draw the "classifica" icon in the top right icon area
  image(menuIconProfilo, 95, 110);   // draw the "profilo" icon in the bottom right icon area
}

/*******************************************************************************************
 * ZGame Logic Section
 * This section of the program is for the logic; how we decide what graphics to show.
 * You can think of it as the section for code that captures and interprets user input (actions)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup, Executes Once When Started, Prepares Program to Run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

import processing.phone.*; // import phone library to go fullscreen
Phone myPhone;             // named reference to phone instance

void setup() // happens only once, when the program starts...
{
  // go fullscreen
  myPhone = new Phone(this); // create new phone instance/controller
  myPhone.fullscreen();      // tell phone to go fullscreen

  loadImages(); // load images
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Mode, Focus & Option Names (Constants)
/////////////////////////////////////////////////////////////////////////////////////////////

// names for each possible focus option of the main menu
int MENUFOCUS_GIOCA = 0;
int MENUFOCUS_AGENDA = 1;
int MENUFOCUS_PROFILO = 2;
int MENUFOCUS_CLASSIFICA = 3;

/////////////////////////////////////////////////////////////////////////////////////////////
// State, Information Collected From Use (Variables)
/////////////////////////////////////////////////////////////////////////////////////////////

// main menu information
int menuFocus = MENUFOCUS_GIOCA; // initially, the main menu focus is on the first item "Gioca"

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw, Executes Forever, Provides User Feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

void draw() // happens repeatedly (according to framerate)...
{
  drawMenu(menuFocus); // draw image for menu with a variable focus
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Keypad Event (User Input Capture & Interpretation)
/////////////////////////////////////////////////////////////////////////////////////////////

void keyReleased() // whenever a key is pressed...
{
  if(menuFocus == MENUFOCUS_GIOCA)  // if the menu is focused on "Gioca"...
  {
    if(keyCode == DOWN){            // if the user pressed down...
      menuFocus = MENUFOCUS_AGENDA; // put the menu focus on "Agenda"
    }
  } else if(menuFocus == MENUFOCUS_AGENDA)  // if the menu is focused on "Agenda"...
  {
    if(keyCode == UP){                      // if the user pressed up...
      menuFocus = MENUFOCUS_GIOCA;          // put the menu focus on "Gioca"
    }
  }
}
