/*  29 November 2007. UIAV Venice mobile services workshop. 
 By Nicholas Zambetti
 Version of ZoGame0l that builds the menu from many images and animates focus changes with easing
 */

/*******************************************************************************************
 * ZGame Graphics Section
 * This section of the program is for the graphics.
 * You can think of it as the section for code that provides feedback to the user (behaviors)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Names Of Graphics & How Load Them
/////////////////////////////////////////////////////////////////////////////////////////////

// named references to graphics
PImage menuBackground;
PImage menuIconFocus;
PImage menuIconGioca;
PImage menuIconAgenda;
PImage menuIconProfilo;
PImage menuIconClassifica;

// function to load all the images for the interface
void loadImages()
{
  menuBackground = loadImage("menuBackground.png");
  menuIconFocus = loadImage("menuIconFocus.png");
  menuIconGioca = loadImage("menuIconGioca.png");
  menuIconAgenda = loadImage("menuIconAgenda.png");
  menuIconProfilo = loadImage("menuIconProfilo.png");
  menuIconClassifica = loadImage("menuIconClassifica.png");
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Screen Drawing Functions
/////////////////////////////////////////////////////////////////////////////////////////////

int animateTo(int current, int target, int speed)
{
  int next = current;          // initially our next step is where we currently are
  if(target < next){           // if we need to make our value smaller...
    next = next - speed;       // make it smaller
    next = max(next, target);  // ensure that we didn't make it smaller than our target value
  } 
  else if(next < target){      // if we need to make our value bigger...
    next = next + speed;       // make it bigger
    next = min(next, target);  // ensure that we didn't make it bigger than our target value
  }
  return next;                 // return our next value
}

int easeTo(int currentOriginal, int targetOriginal, int speed)
{
  // make values large for math
  int current = currentOriginal * 1000; // make current value large for math (e.g. 2 becomes 2000)
  int target = targetOriginal * 1000;   // make target value large for math  (e.g. 33 becomes 33000)

  // do math to calculate our next value
  int change = target - current;     // find out how much change there is (e.g. 33000 - 2000 = 31000)
  int changeLittle = change / speed; // make the change a little change   (e.g. 31000 / 4 = 7750)
  int next = current + changeLittle; // change the current value a little (e.g. 2000 + 7750 = 9750)

  // make next value small for screen
  next = next / 1000;

  // if our little change was so little that we didn't move...
  if(next == currentOriginal){
    next = targetOriginal; // our next step is our target
  }

  return next; // return our next value (e.g. 9750 / 1000 = 9, remember that we started with 2)
}

// function to draw the menu with specified focus
int menuIconFocusX = 12; // begin with menuIconFocus X at Gioca X
int menuIconFocusY = 29; // begin with menuIconFocus Y at Gioca Y

void drawMenu(int focus)
{
  // draw background
  image(menuBackground, 0, 0);       // draw background image for the menu area

  // calculate position of focus highlight for the icon in focus
  if(focus == MENUFOCUS_GIOCA){      // if we are focused on "gioca"...
    // final position is x:12 y:29
    menuIconFocusX = easeTo(menuIconFocusX, 12, 10); // ease to our destination (try using 2 instead of 10 to make it faster)
    menuIconFocusY = easeTo(menuIconFocusY, 29, 10); // ease to our destination (try using 2 instead of 10 to make it faster)
  }
  if(focus == MENUFOCUS_AGENDA){     // if we are focused on "agenda"...
    // final position is x:12 y:107
    menuIconFocusX = 12;
    menuIconFocusY = 107;
  }
  if(focus == MENUFOCUS_CLASSIFICA){ // if we are focused on "classifica"...
    // final position is x:92 y:29
    menuIconFocusX = 92;
    menuIconFocusY = 29;
  }
  if(focus == MENUFOCUS_PROFILO){    // if we are focused on "profilo"...
    // final position is x:92 y:107
    menuIconFocusX = 92;
    menuIconFocusY = 107;
  }

  // draw the focus highlight in the calculated position 
  image(menuIconFocus, menuIconFocusX, menuIconFocusY); // often, the focus is drawn later on

  // draw main content, icons
  image(menuIconGioca, 15, 32);      // draw the "gioca" icon in the top left icon area
  image(menuIconAgenda, 15, 110);    // draw the "agenda" icon in the bottom left icon area
  image(menuIconClassifica, 95, 32); // draw the "classifica" icon in the top right icon area
  image(menuIconProfilo, 95, 110);   // draw the "profilo" icon in the bottom right icon area
}

/*******************************************************************************************
 * ZGame Logic Section
 * This section of the program is for the logic; how we decide what graphics to show.
 * You can think of it as the section for code that captures and interprets user input (actions)
 *******************************************************************************************/

/////////////////////////////////////////////////////////////////////////////////////////////
// Setup, Executes Once When Started, Prepares Program to Run (Logic Initialization)
/////////////////////////////////////////////////////////////////////////////////////////////

import processing.phone.*; // import phone library to go fullscreen
Phone myPhone;             // named reference to phone instance

void setup() // happens only once, when the program starts...
{
  // go fullscreen
  myPhone = new Phone(this); // create new phone instance/controller
  myPhone.fullscreen();      // tell phone to go fullscreen

    loadImages(); // load images
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Mode, Focus & Option Names (Constants)
/////////////////////////////////////////////////////////////////////////////////////////////

// names for each possible focus option of the main menu
int MENUFOCUS_GIOCA = 0;
int MENUFOCUS_AGENDA = 1;
int MENUFOCUS_PROFILO = 2;
int MENUFOCUS_CLASSIFICA = 3;

/////////////////////////////////////////////////////////////////////////////////////////////
// State, Information Collected From Use (Variables)
/////////////////////////////////////////////////////////////////////////////////////////////

// main menu information
int menuFocus = MENUFOCUS_GIOCA; // initially, the main menu focus is on the first item "Gioca"

/////////////////////////////////////////////////////////////////////////////////////////////
// Draw, Executes Forever, Provides User Feedback (Logic Repetition)
/////////////////////////////////////////////////////////////////////////////////////////////

void draw() // happens repeatedly (according to framerate)...
{
  drawMenu(menuFocus); // draw image for menu with a variable focus
}

/////////////////////////////////////////////////////////////////////////////////////////////
// Keypad Event (User Input Capture & Interpretation)
/////////////////////////////////////////////////////////////////////////////////////////////

void keyReleased() // whenever a key is pressed...
{
  if(menuFocus == MENUFOCUS_GIOCA)  // if the menu is focused on "Gioca"...
  {
    if(keyCode == DOWN){            // if the user pressed down...
      menuFocus = MENUFOCUS_AGENDA; // put the menu focus on "Agenda"
    }
  } 
  else if(menuFocus == MENUFOCUS_AGENDA)  // if the menu is focused on "Agenda"...
  {
    if(keyCode == UP){                      // if the user pressed up...
      menuFocus = MENUFOCUS_GIOCA;          // put the menu focus on "Gioca"
    }
  }
}
